==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/Anasazi/AnasaziTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Anasazi::anasazi" for configuration "RELEASE"
set_property(TARGET Anasazi::anasazi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::anasazi PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanasazi.so.15.0"
  IMPORTED_SONAME_RELEASE "libanasazi.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::anasazi )
list(APPEND _cmake_import_check_files_for_Anasazi::anasazi "${_IMPORT_PREFIX}/lib/libanasazi.so.15.0" )

# Import target "Anasazi::anasaziepetra" for configuration "RELEASE"
set_property(TARGET Anasazi::anasaziepetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::anasaziepetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanasaziepetra.so.15.0"
  IMPORTED_SONAME_RELEASE "libanasaziepetra.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::anasaziepetra )
list(APPEND _cmake_import_check_files_for_Anasazi::anasaziepetra "${_IMPORT_PREFIX}/lib/libanasaziepetra.so.15.0" )

# Import target "Anasazi::ModeLaplace" for configuration "RELEASE"
set_property(TARGET Anasazi::ModeLaplace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::ModeLaplace PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libModeLaplace.so.15.0"
  IMPORTED_SONAME_RELEASE "libModeLaplace.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::ModeLaplace )
list(APPEND _cmake_import_check_files_for_Anasazi::ModeLaplace "${_IMPORT_PREFIX}/lib/libModeLaplace.so.15.0" )

# Import target "Anasazi::anasazitpetra" for configuration "RELEASE"
set_property(TARGET Anasazi::anasazitpetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::anasazitpetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanasazitpetra.so.15.0"
  IMPORTED_SONAME_RELEASE "libanasazitpetra.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::anasazitpetra )
list(APPEND _cmake_import_check_files_for_Anasazi::anasazitpetra "${_IMPORT_PREFIX}/lib/libanasazitpetra.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/Anasazi/AnasaziTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Anasazi::anasazi" for configuration "RELEASE"
set_property(TARGET Anasazi::anasazi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::anasazi PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanasazi.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libanasazi.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::anasazi )
list(APPEND _cmake_import_check_files_for_Anasazi::anasazi "${_IMPORT_PREFIX}/lib/libanasazi.so.15.1.1" )

# Import target "Anasazi::anasaziepetra" for configuration "RELEASE"
set_property(TARGET Anasazi::anasaziepetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::anasaziepetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanasaziepetra.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libanasaziepetra.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::anasaziepetra )
list(APPEND _cmake_import_check_files_for_Anasazi::anasaziepetra "${_IMPORT_PREFIX}/lib/libanasaziepetra.so.15.1.1" )

# Import target "Anasazi::ModeLaplace" for configuration "RELEASE"
set_property(TARGET Anasazi::ModeLaplace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::ModeLaplace PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libModeLaplace.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libModeLaplace.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::ModeLaplace )
list(APPEND _cmake_import_check_files_for_Anasazi::ModeLaplace "${_IMPORT_PREFIX}/lib/libModeLaplace.so.15.1.1" )

# Import target "Anasazi::anasazitpetra" for configuration "RELEASE"
set_property(TARGET Anasazi::anasazitpetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Anasazi::anasazitpetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanasazitpetra.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libanasazitpetra.so.15"
  )

list(APPEND _cmake_import_check_targets Anasazi::anasazitpetra )
list(APPEND _cmake_import_check_files_for_Anasazi::anasazitpetra "${_IMPORT_PREFIX}/lib/libanasazitpetra.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
